@@ -1,11 +1,13 @@
 """
-base
+Base Plugin Classes
 
 """
+import csv
 import logging
 from os import path
 import requests
 import socket
+import tempfile
 import time
 import urlparse
 
@@ -254,14 +256,21 @@ class SocketStatsPlugin(Plugin):
         else:
             return connection
 
-    def fetch_data(self, connection):
+    def fetch_data(self, connection, read_till_empty=False):
         """Read the data from the socket
 
         :param  socket connection: The connection
 
         """
         LOGGER.debug('Fetching data')
-        return connection.recv(self.SOCKET_RECV_MAX)
+        received = connection.recv(self.SOCKET_RECV_MAX)
+        while read_till_empty:
+            chunk = connection.recv(self.SOCKET_RECV_MAX)
+            if chunk:
+                received += chunk
+            else:
+                break
+        return received
 
     def poll(self):
         """This method is called after every sleep interval. If the intention
@@ -386,9 +395,8 @@ class HTTPStatsPlugin(Plugin):
 
         """
         kwargs = {'url': self.stats_url}
-        if (self.config.get('scheme') == 'https' and
-                self.config.get('verify_ssl_cert')):
-            kwargs['verify'] = self.config.get('verify_ssl_cert', True)
+        if self.config.get('scheme') == 'https':
+            kwargs['verify'] = self.config.get('verify_ssl_cert', False)
 
         if 'username' in self.config and 'password' in self.config:
             kwargs['auth'] = (self.config['username'], self.config['password'])
@@ -397,6 +405,39 @@ class HTTPStatsPlugin(Plugin):
         return kwargs
 
 
+class CSVStatsPlugin(HTTPStatsPlugin):
+    """Extend the Plugin overriding poll for targets that provide JSON output
+    for stats collection
+
+    """
+    def fetch_data(self):
+        """Fetch the data from the stats URL
+
+        :rtype: dict
+
+        """
+        data = super(CSVStatsPlugin, self).fetch_data()
+        if not data:
+            return dict()
+        temp = tempfile.TemporaryFile()
+        temp.write(data)
+        temp.seek(0)
+        reader = csv.DictReader(temp)
+        data = list()
+        for row in reader:
+            data.append(row)
+        temp.close()
+        return data
+
+    def poll(self):
+        """Poll HTTP JSON endpoint for stats data"""
+        self.initialize()
+        data = self.fetch_data()
+        if data:
+            self.add_datapoints(data)
+        self.finish()
+
+
 class JSONStatsPlugin(HTTPStatsPlugin):
     """Extend the Plugin overriding poll for targets that provide JSON output
     for stats collection
