@@ -15,7 +15,7 @@ class Memcached(base.SocketStatsPlugin):
     DEFAULT_PORT = 11211
     KEYS = ['curr_connections',
             'curr_items',
-            'connection_struct',
+            'connection_structures',
             'cmd_get',
             'cmd_set',
             'cmd_flush',
@@ -61,7 +61,7 @@ class Memcached(base.SocketStatsPlugin):
         self.add_gauge_value('Connection/Count', '',
                              stats['curr_connections'])
         self.add_gauge_value('Connection/Structures', '',
-                             stats['connection_struct'])
+                             stats['connection_structures'])
         self.add_derive_value('Connection/Yields', '',
                               stats['conn_yields'])
         self.add_derive_value('Evictions', '', stats['evictions'])
@@ -130,7 +130,7 @@ class Memcached(base.SocketStatsPlugin):
         # Back fill any missed data
         for key in self.KEYS:
             if key not in values:
-                LOGGER.warning('Populating missing element: %s', key)
+                LOGGER.info('Populating missing element with 0: %s', key)
                 values[key] = 0
 
         # Return the values dict
